
% Computes impulse response for new keynesian model
% makes plots for MM Fisher and Occam. 

% The version in the root directory has many abandoned 
% graphs. This makes final graphs for the paper. 

close all
clear all

global global_pars 
% globals needed for search to find zero fiscal response

% parameters
b = 0.97; % beta
k = 0.2; % kappa
s = 1; % sigma 
xi =0.1; % xi interest elasticity of money demand
mc =0; % money to output ratio
phipi = 1.5; % taylor parameter for inferring supporting taylor rule
mamax = 50; % how many ir to calculate
printgraph = 1; % set to 0 to play with program without overwriting graphics. 
xlimits = [-5 7]; % range for x axis of impulse response plots

maxt = 50; % was 10 % how far forward to run irs 
itargt = [zeros(10,1);1;ones(maxt,1)]; %interest target
itargt2 = [zeros(10,1);1;0.7.^(1:maxt)']; %interest target
itargt3 = [zeros(10,1);0.25; 0.25; 0.5; 0.5; 0.75; 0.75; 1; 1; 1.25; 1.25; 1.25*ones(maxt-10+1,1) ]; %interest target
itargt4 = [zeros(10,1);(0.7.^(1:maxt+1)'-0.67.^(1:maxt+1)')]/(0.7-0.67); %interest target
itargt5 = [zeros(10,1);ones(10,1);zeros(maxt-9,1)]; % for narayana
imtargt = 0; % target for interest on money. 0 will fill out to zeros

tim = (-10:maxt)'; % must be symmetric! 
t0 = 11; % index of t = 0

part1 = 1; % basic
part2 = 1; % multiple equilibria
part3 = 1; % money
part4 = 1; % lagged pi in phillips curve

% part 1: basic
if part1;
    
    % frictionless 
    
    % calculate fiscal theory versions. 
    x = load('Hall_data/selected_treasury_data.txt'); 
    mat = x(:,1);
    B = x(:,2); 
    y = x(:,3); 
    Y = 1+y/100;
    Q = (1./(Y.^mat));
    F = [1;Q(1:end-1)]./Q;
    F1 = F+0.01; 
    F2 = F; 
    F2(1:3) = F(1:3)+0.01; % short lived
    F3 = F; 
    F3(4:end) = F(4:end)+0.01; %delayed
    F4 = F; 
    F4(4:6) = F(4:6)+0.01; %delayed and short lived 
    %Qcheck = 1./cumprod(F); 
    Q1 = 1./cumprod(F1);
    Q2 = 1./cumprod(F2); 
    Q3 = 1./cumprod(F3); 
    Q4 = 1./cumprod(F4); 
    V0 = sum(B.*Q);
    V1 = sum(B.*Q1);
    V2 = sum(B.*Q2);
    V3 = sum(B.*Q3); 
    V4 = sum(B.*Q4); 
    p1 = (V1/V0-1)*100;
    p2 = (V2/V0-1)*100;
    p3 = (V3/V0-1)*100;
    p4 = (V4/V0-1)*100;
    
    
    % without long term 
    figure
    plot(tim,itargt+0.03,'-bv','linewidth',3,'markersize',7);
    hold on
    pit = [itargt(1); itargt(1:end-1)]; % pit = i(t-1)
   % plot(tim,pit,'-rs','linewidth',2);
    pit1 = pit*ones(1,5);
    pit1(t0,:) = pit1(t0,:)+[1.5 1 0.5 -0.5 -1];
    plot(tim,0*tim,'-k')
    plot(tim,pit1,'--ms','linewidth',2);
    plot(tim,pit,'-rs','linewidth',3,'markersize',7);
    axis([-3 3  -1.5 1.5]);
    %legend('i','\pi','location','NorthWest');
    xlabel('Time');
    ylabel('Percent response')
    text(0.2,1.15,'interest rate i','fontsize',16,'color','b','backgroundcolor','w')
    text(0.35,0.2,'inflation \pi','fontsize',16,'color','r','backgroundcolor','w')
    text(0.4,-1,...
        {'\pi with fiscal shocks';'also \pi with long term debt'},...
        'fontsize',16,'color','m','backgroundcolor','w')
    text(-0.1,1,'Standard NK \rightarrow','color','m','fontsize',16,'horizontalalignment','r')
    
    if printgraph; print -depsc2 nk_ir_nofric.eps; end;
   
    % anticipated
   
    figure
    plot(tim,itargt+0.03,'-bv','linewidth',3);
    hold on
    pit = [itargt(1); itargt(1:end-1)]; % pit = i(t-1)
    plot(tim,pit,'-rs','linewidth',2);
    pit1 = pit*ones(1,4);
    pit1(t0-3,:) = pit1(t0-3,:)+[ 1 0.5 -0.5 -1];
    plot(tim,0*tim,'-k')
    plot(tim,pit1,'--ms','linewidth',2);
    plot(tim,pit,'-rs','linewidth',3);
    axis([-5 3  -1.5 1.5]);
    %legend('i','\pi','location','NorthWest');
    xlabel('Time');
    ylabel('Percent response')
    text(-0.2,1.15,'interest rate i','fontsize',16,'color','b','backgroundcolor','w')
    text(0.5,0.3,'inflation \pi','fontsize',16,'color','r','backgroundcolor','w')
    text(-2.5,-1,...
        {'\pi, with fiscal shocks';'also \pi with long term debt'},... 
   'fontsize',16,'color','m','backgroundcolor','w')
    
    
    if printgraph; print -depsc2 nk_ir_nofric_2.eps; end;
     
     
    %simple nk model
    
    [pit,xt,pit_unex,xt_unex,r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt,0,t0,b,k,s,xi,0,0,mamax);
    
    figure
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim,pit,'-rs','linewidth',2);
    plot(tim,xt,'-ko','linewidth',2);
    plot(tim,0*tim,'-k')
    plot(tim,pit_unex,'--ms','linewidth',2);
    plot(tim,xt_unex,'--bo','linewidth',2);
    plot(tim,pit,'-rs','linewidth',2);
    plot(tim,xt,'-ko','linewidth',2);
    text(2,itargt(find(tim==2)),'interest rate i','color', [0    0.4470    0.7410],'backgroundcolor','w','fontsize',16);
    text(2,pit(find(tim==2)),'inflation \pi','color', 'r','backgroundcolor','w','fontsize',16);
    text(2,xt(find(tim==2)),'output gap x','color', 'k','backgroundcolor','w','fontsize',16);
    axis([xlimits  -inf 1.1]);
    %legend('i','\pi','x','location','NorthWest');
    xlabel('Time');
    ylabel('Percent response')
    if printgraph; print -depsc2 nk_ir_1.eps; end;
    
           
    % with AR(1) decaying target
    [pit,xt,pit_unex,xt_unex,r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt2,0,t0,b,k,s,xi,0,0,mamax);
   
    figure
    plot(tim,itargt2,'-gv','linewidth',2);
    hold on
    plot(tim,pit,'-rs','linewidth',2);
    plot(tim,xt,'-ko','linewidth',2);
    plot(tim,pit_unex,'--ms','linewidth',2);
    plot(tim,xt_unex,'--bo','linewidth',2);
    plot(tim,0*tim,'-k')
    plot(tim,pit,'-rs','linewidth',2);
    plot(tim,xt,'-ko','linewidth',2);
  
    axis([xlimits  -inf 1.1]);
    %legend('i','\pi','x','location','NorthWest');
    text(1,0.8,'interest rate i','color', [0    0.4470    0.7410],'backgroundcolor','w','fontsize',16);
    text(0,0.33,'inflation \pi','horizontalalignment','r','color', 'r','backgroundcolor','w','fontsize',16);
    text(1,-0.4,'output gap x','color', 'k','backgroundcolor','w','fontsize',16);
    
    xlabel('Time');
    ylabel('Percent response')
    if printgraph; print -depsc2 nk_ir_1_decay.eps; end;
    
 
end;

if part2;
    
    % Long terme debt  in nk model 
    % copied from fiscal shocks below and adapted 
    %limits_lr = [-5 7 -1.6 1.2]; % common axes for all long run 
    onebiggraph = 1; % do this section as two two one four panel graph or as 4 figures
    
    % find basic IR -- unexpected shock
    Tb = 0;  
    [pit,xt,pit_unex,xt_unex,r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt,0,t0,b,k,s,xi,0,0,mamax);
   
    
     % uses debt data loaded above . 
    x = load('Hall_data/selected_treasury_data.txt'); 
    mat = x(:,1);
    B = x(:,2); 
    y = x(:,3); 
    Y = 1+y/100;
    Q = (1./(Y.^mat));
    F = [1;Q(1:end-1)]./Q;
    F1 = F; 
    F1(1+Tb:end) = F+itargt(t0)/100; 
    % step function hard wired -- fix if you do AR(1). Lets bonds go further than itargt
     %Qcheck = 1./cumprod(F); 
    Q1 = 1./cumprod(F1);
    V0 = sum(B.*Q);
    V1 = sum(B.*Q1);
    Vterm = V1/V0; % use zero to signal one period debt calculation
    
    % find delta such that no surplus is required
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,Vterm,1};
    ds0 = fzero(@f_finds,0);
    d0 = [ 0 ds0   ];
    [bigpit, bigxt, dsbig] = fn_add_delta(tim,Tb,l1,l2,d0,pit,xt,b,s,k,t0,Vterm,1);
   
    % version ignoring real rate variation 
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,Vterm,0};
    ds0_no_r = fzero(@f_finds,0);
    [bigpit_no_r, bigxt_no_r, dsbig_no_r] = fn_add_delta(tim,Tb,l1,l2,ds0_no_r,pit,xt,b,s,k,t0,Vterm,0);
    
    figure
    if onebiggraph; 
        subplot(2,2,1)
        fonts_lr = 10;
    end;
    if ~onebiggraph
        fonts_lr = 16;
    end;
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim,[zeros(t0-1,1); bigpit(t0:end,2)],'-rs','linewidth',2); %bigpi has nans
    %plot(tim,[zeros(t0-Tb-1,1); cumsum(bigpit(t0-Tb:end,2))],'-bs','linewidth',2); 

    %plot(tim,[zeros(t0-1,1); pit(t0:end)],'--rs','linewidth',1); % short term debt case -- dropped because too confusing
    %plot(tim,[zeros(t0-1,1); xt(t0:end)],'--ko','linewidth',1); %short term case
    plot(tim,[zeros(t0-1,1); bigxt(t0:end,2)],'-ko','linewidth',2);
    plot(tim,[zeros(t0-Tb-1,1); bigpit_no_r(t0-Tb:end,1)],'--ms','linewidth',2);
    
    plot(tim,0*tim,'-k');
    %axis(limits_lr);
    %limits_lr = [-5 7 -1.6 1.2]
    axis([-3 7 -5 1.2])
    %legend('i','\pi','x');
    for indx = 1:size(d0,2);
      %  text(-0.20,bigpit(t0,indx),['\Deltas=' num2str(dsbig(indx),'%3.2f')],...
      %     'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')
    end;
    text(3,-1.5,'Output gap x','color','k','backgroundcolor','w','fontsize',fonts_lr)
    text(4.2,0.4,'\pi','color','r','fontsize',fonts_lr)
    text(1,-4,'Inflation \pi, no r effect','color','m','backgroundcolor','w','fontsize',fonts_lr)
    title('Unexpected permanent rate rise','fontsize',fonts_lr)
    xlabel('Time','fontsize',fonts_lr);
    ylabel('Percent response','fontsize',fonts_lr)
    if printgraph & ~onebiggraph; print -depsc2 nk_ir_lr_1.eps; end;
 
    disp('long run graph min x panel 1');
    disp(min(bigxt(:,2)));
    
    % Repeat, but now with announcement 3 periods earlier
    
    Tb = 3;
    F1 = F; 
    F1(1+Tb:end) = F(1+Tb:end)+itargt(t0)/100; 
    Q1 = 1./cumprod(F1);
    V0 = sum(B.*Q);
    V1 = sum(B.*Q1);
    Vterm = V1/V0; % use zero to signal one period debt calculation
    
    % find delta such that no surplus is required
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,Vterm,1};
    ds0 = fzero(@f_finds,0);
    
    d0 = [ 0 ds0   ];
    [bigpit, bigxt, dsbig] = fn_add_delta(tim,Tb,l1,l2,d0,pit,xt,b,s,k,t0,Vterm,1);

    
    if ~onebiggraph;
        figure 
    end
    if onebiggraph; 
        subplot(2,2,2)
    end;
    
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim,[zeros(t0-Tb-1,1); bigpit(t0-Tb:end,2)],'-rs','linewidth',2); %bigpi has nans
   % plot(tim,[zeros(t0-Tb-1,1); cumsum(bigpit(t0-Tb:end,2))],'-bs','linewidth',2); 

    %plot(tim,[zeros(t0-Tb-1,1); pit(t0-Tb:end)],'--rs','linewidth',1);
   % plot(tim,[zeros(t0-Tb-1,1); xt(t0-Tb:end)],'--ko','linewidth',1);
    plot(tim,[zeros(t0-Tb-1,1); bigxt(t0-Tb:end,2)],'-ko','linewidth',2); 
    
    plot(tim,0*tim,'-k');
    %limits_lr = [-5 7 -1.6 1.2]
    axis([-5 7 -5 1.2])  
    %legend('i','\pi','x');
    %    text(-Tb-0.20,bigpit(t0-Tb,1)+0.1,['\Deltas=' num2str(dsbig(1),'%3.2f')],...
    %        'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')
    
    %    text(-Tb-0.20,bigpit(t0-Tb,2)-0.1,['\Deltas=' num2str(dsbig(2),'%3.2f')],...
    %        'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')   
        
    text(1,-2,'Output gap x','color','k','backgroundcolor','w','fontsize',fonts_lr)
    text(4,0.4,'\pi','color','r','backgroundcolor','w','fontsize',fonts_lr)
    title('Expected permanent rate rise','fontsize',fonts_lr)
    xlabel('Time','fontsize',fonts_lr);
    ylabel('Percent response','fontsize',fonts_lr)
    if printgraph & ~onebiggraph; print -depsc2 nk_ir_lr_2.eps; end;
    disp('long run graph min x panel 2');
    disp(min(bigxt(:,2)));
    
    % repeat, but for AR(1) unexpected shock -- like VAR 
    Tb = 0; 
    [pit,xt,pit_unex,xt_unex,r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt2,0,t0,b,k,s,xi,0,0,mamax);
   
    F1 = F; 
    F1(1+Tb:end) = F(1+Tb:end)+itargt2(t0:t0+size(F1,1)-Tb-1)/100; 
    Q1 = 1./cumprod(F1);
    V0 = sum(B.*Q);
    V1 = sum(B.*Q1);
    Vterm = V1/V0; % use zero to signal one period debt calculation
    
    % find delta such that no surplus is required
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,Vterm,1};
    ds0 = fzero(@f_finds,0);
    
    d0 = [ 0 ds0   ];
    [bigpit, bigxt, dsbig] = fn_add_delta(tim,Tb,l1,l2,d0,pit,xt,b,s,k,t0,Vterm,1);
    
    if ~onebiggraph
        figure
    end
    if onebiggraph; 
        subplot(2,2,3)
    end;
    
    plot(tim,itargt2,'-gv','linewidth',2);
    hold on
    plot(tim,[zeros(t0-1,1); bigpit(t0:end,2)],'-rs','linewidth',2); %bigpi has nans
    %plot(tim,[zeros(t0-Tb-1,1); cumsum(bigpit(t0-Tb:end,2))],'-bs','linewidth',2); 

    %plot(tim,[zeros(t0-1,1); pit(t0:end)],'--rs','linewidth',1);
    %plot(tim,[zeros(t0-1,1); xt(t0:end)],'--ko','linewidth',1);
    plot(tim,[zeros(t0-1,1); bigxt(t0:end,2)],'-ko','linewidth',2);
    
    plot(tim,0*tim,'-k');
   %axis([-3 7 -5 1.2])
    axis([-3 7 -1.6 1.2]) 
    %legend('i','\pi','x');
   %  text(-0.20,bigpit(t0,1)+0.1,['\Deltas=' num2str(dsbig(1),'%3.2f')],...
   %         'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')
        
    % text(-0.20,bigpit(t0,2)-0.1,['\Deltas=' num2str(dsbig(2),'%3.2f')],...
    %        'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')
     text(1,1,'Interest rate','color','g','fontsize',fonts_lr)
    text(2,-0.7,'Output gap x','color','k','backgroundcolor','w','fontsize',fonts_lr)
    text(0.3,-0.5,'\pi','color','r','backgroundcolor','w','fontsize',fonts_lr)
    title('Unexpected AR(1) rate rise','fontsize',fonts_lr)
    xlabel('Time','fontsize',fonts_lr);
    ylabel('Percent response','fontsize',fonts_lr)
    if printgraph & ~onebiggraph; print -depsc2 nk_ir_lr_3.eps; end;
     disp('long run graph min x panel 3');
    disp(min(bigxt(:,2)));
     
     % finally, but for AR(1) expected shock -- like VAR 
    Tb = 3; 
    F1 = F; 
    F1(1+Tb:end) = F(1+Tb:end)+itargt2(t0:t0+size(F1,1)-Tb-1)/100; 
    Q1 = 1./cumprod(F1);
    V0 = sum(B.*Q);
    V1 = sum(B.*Q1);
    Vterm = V1/V0; % use zero to signal one period debt calculation
    
    % find delta such that no surplus is required
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,Vterm,1};
    ds0 = fzero(@f_finds,0);
    
    d0 = [ 0 ds0   ];
    [bigpit, bigxt, dsbig] = fn_add_delta(tim,Tb,l1,l2,d0,pit,xt,b,s,k,t0,Vterm,1);
    
    if ~onebiggraph
        figure
    end
    if onebiggraph; 
        subplot(2,2,4)
    end;
    
    plot(tim,itargt2,'-gv','linewidth',2);
    hold on
    plot(tim,[zeros(t0-Tb-1,1); bigpit(t0-Tb:end,2)],'-rs','linewidth',2); %bigpi has nans
    plot(tim,[zeros(t0-Tb-1,1); pit(t0-Tb:end)],'--rs','linewidth',1);
    %plot(tim,[zeros(t0-Tb-1,1); xt(t0-Tb:end)],'--ko','linewidth',1);
    plot(tim,[zeros(t0-Tb-1,1); bigxt(t0-Tb:end,2)],'-ko','linewidth',2);
    
    plot(tim,0*tim,'-k');
    axis([-5 7 -1.6 1.2])  
    %legend('i','\pi','x');
    % text(-Tb-0.20,bigpit(t0-Tb,1)+0.1,['\Deltas=' num2str(dsbig(1),'%3.2f')],...
    %        'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')
        
    % text(-Tb-0.20,bigpit(t0-Tb,2)-0.1,['\Deltas=' num2str(dsbig(2),'%3.2f')],...
    %        'HorizontalAlignment','right','color','r','fontsize',fonts_lr,'backgroundcolor','w')
     text(1,1,'Interest rate','color','g','fontsize',fonts_lr)
    text(1,-0.7,'Output gap x','color','k','backgroundcolor','w','fontsize',fonts_lr)
     text(-2,-0.4,'\pi','color','r','backgroundcolor','w','fontsize',fonts_lr)
      
     % text(2,-0.7,{'Output gap x',['min x = ' num2str(min(bigxt(:,2)),'%3.2f')]},'color','k','backgroundcolor','w','fontsize',fonts_lr)
    %text(4,0.4,'Inflation \pi','color','r','backgroundcolor','w','fontsize',fonts_lr)
    title('Expected AR(1) rate rise','fontsize',fonts_lr)
    xlabel('Time','fontsize',fonts_lr);
    ylabel('Percent response','fontsize',fonts_lr)
    if printgraph & ~onebiggraph; print -depsc2 nk_ir_lr_4.eps; end;
     disp('long run graph min x panel 4');
    disp(min(bigxt(:,2)));
     
    if onebiggraph
        print -depsc2 nk_ir_lr_big.eps
    end
       
    
   % ***************
    
    % delta shocks in nk model with short term debt
    % show some alternative solutions, which add geometric decay
    % find s = 0 solution

    Tb = 0;
    [pit,xt,pit_unex,xt_unex,r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt,0,t0,b,k,s,xi,0,0,mamax);
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,1,1};
    ds0 = fzero(@f_finds,0.5);
    
    % find other solutions
    
    d0 = [ ds0 1.2-pit(t0) 1-pit(t0) 0-pit(t0) -0.5-pit(t0) ];
    [bigpit, bigxt, dsbig] = fn_add_delta(tim,Tb,l1,l2,d0,pit,xt,b,s,k,t0,1,1);
    [pit0, xt0, ds0] = fn_add_delta(tim,Tb,l1,l2,0,pit,xt,b,s,k,t0,1,1);
    % 0 separate to give different color and fdlabel position
    figure
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim(t0:end),pit(t0:end),'-rs','linewidth',2);
    plot(tim,bigpit,'--ms','linewidth',2);
    plot(tim,0*tim,'-k');
    %axis([xlimits  -0.6 1.3]);
    axis([xlimits  -inf inf]); 
    %legend('i','\pi','x');
    [sortpi0, indxsort] = sort(-bigpit(t0,:)');
    lbls = ['A'; 'B'; 'C'; 'D'; 'E'; 'F'; 'G'];
    for indx = 1:size(bigpit,2);
        text(-0.50,bigpit(t0,indxsort(indx)),[lbls(indx,:) ',\Deltas=' num2str(dsbig(indxsort(indx)),'%3.2f')],...
            'HorizontalAlignment','right','color','m','fontsize',14,'backgroundcolor','w')
    end;
    text(-0.50,pit0(t0)-0.1,['\delta=0',',\Deltas=' num2str(ds0,'%3.2f')],...
            'HorizontalAlignment','right','color','r','fontsize',14,'backgroundcolor','w')
    title('Inflation')
    xlabel('Time');
    ylabel('Percent response')
    if printgraph; print -depsc2 nk_ir_2.eps; end;

    
    % Repeat, but now with announcement 3 periods earlier
    
    Tb = 3;
    global_pars = {tim, l1, l2, pit, xt, t0, s, b, k, Tb,1,1};
    ds0 = fzero(@f_finds,0.5);
    
    % find other solutions -- these are the same as before, adding the same
    % delta at time 0
    
    d0 = [ ds0 1.2-pit(t0) 1-pit(t0) 0-pit(t0) -0.5-pit(t0) ];
    [bigpit, bigxt, dsbig] = fn_add_delta(tim,Tb,l1,l2,d0,pit,xt,b,s,k,t0,1,1);
    [pit0, xt0, ds0] = fn_add_delta(tim,Tb,l1,l2,0,pit,xt,b,s,k,t0,1,1);
    
    figure
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim,bigpit,'--ms','linewidth',2);
    plot(tim,pit0,'-rs','linewidth',2);
    plot(tim,0*tim,'-k');
    %axis([-6 10 -1.8 2]);
    axis([-6 10 -inf inf]);
    xlabel('Time');
    ylabel('Percent response')
    %legend('i','\pi','x');
    [sortpi0, indxsort] = sort(-bigpit(t0-3,:)');
    title('Inflation')
    for indx = 1:size(bigpit,2);
        text(-Tb-0.50,bigpit(t0-Tb,indxsort(indx)),[lbls(indx) ', \Deltas=' num2str(dsbig(indxsort(indx)),'%3.2f')],...
            'HorizontalAlignment','right','color','m','fontsize',14,'backgroundcolor','w')
    end;
    text(-Tb-0.50,pit0(t0-Tb)+0.4,['\delta=0',',\Deltas=' num2str(ds0,'%3.2f')],...
            'HorizontalAlignment','right','color','r','fontsize',14,'backgroundcolor','w')
    
    if printgraph; print -depsc2 nk_ir_3.eps; end;
    
       
end;

% --------------------
% model with money 
% -------------------


if part3;
    
    bigplot = 1 % produces 4 panel plot, inflaiton, output, permanent transtiorty
    
    % basic plot with money and step function; 
    mcv = [0 2 4 ]'; % money to output rati
    clear pit xt pit_unex xt_unex;
    for indx=1:size(mcv,1);
        [pit(:,indx),xt(:,indx),pit_unex(:,indx),xt_unex(:,indx),r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt,imtargt,t0,b,k,s,xi,mcv(indx),0,mamax);
    end;
    
    % inflation 
    figure
    if bigplot
        subplot(2,2,1)
    end
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim,pit_unex(:,1),'--ms','linewidth',2);
    plot(tim,pit(:,1),'-rs','linewidth',2);
    plot(tim,pit,'-rs','linewidth',2);
    plot(tim,pit_unex,'--ms','linewidth',2);
    plot(tim,0*tim,'-k')
    axis([xlimits  -inf 1.1]);
    % text(1.5,pit_unex(2+t0,1),['m/c=' num2str(mcv(1),'%1.0f')],...
    %     'color','r','backgroundcolor','w','horizontalalignment','r');
    % text(1.5,pit(1+t0,end),['m/c=' num2str(mcv(end),'%1.0f')],...
    %     'color','r','backgroundcolor','w','horizontalalignment','l');
    
    if bigplot;
        text(-4,0.2,'m/c=0','color','r')
        text(1,-0.3,'m/c=4','color','r')
    end
    if ~bigplot
          for indx = 1:size(mcv,1); 
          text(0,pit(0+t0,indx),['m/c=' num2str(mcv(indx),'%1.0f')],...
         'color','r','backgroundcolor','w','horizontalalignment','l');
    end 
        legend('i','Un\pi, expected','\pi, expected','location','NorthWest');
     end
        xlabel('Time');
    ylabel('Percent response')
    title('Inflation')
    if (~bigplot)&printgraph
        print -depsc2 nk_ir_m.eps;
    end
    
    if bigplot
        subplot(2,2,2)
    else
        figure
    end
    plot(tim,itargt,'-gv','linewidth',2);
    hold on
    plot(tim,xt_unex(:,1),'--bo','linewidth',2);
    plot(tim,xt(:,1),'-ko','linewidth',2);
    plot(tim,0*tim,'-k')
    plot(tim,xt,'-ko','linewidth',2);
    plot(tim,xt_unex(:,2:end),'--bo','linewidth',2);
    axis([xlimits  -inf 1.1]);
     
    if bigplot
        text(-4,0.6,'m/c=4','color','k')
        text(-4,-0.7,'m/c=0','color','k')
    end
    if ~bigplot
        text(1.5,xt(2+t0,1),['m/c=' num2str(mcv(1),'%1.0f')],...
            'color','k','backgroundcolor','w','horizontalalignment','r');
        text(1.5,xt(1+t0,end),['m/c=' num2str(mcv(end),'%1.0f')],...
            'color','k','backgroundcolor','w','horizontalalignment','l');
        for indx = 1:size(mcv,1);
            text(-2,xt(-2+t0,indx),['m/c=' num2str(mcv(indx),'%1.0f')],...
                'color','k','backgroundcolor','w','horizontalalignment','r');
        end
        legend('i','x, unexpected','x, expected','location','NorthWest');
    end
    xlabel('Time');
    title('Output')
    ylabel('Percent response')
    if (~bigplot) & printgraph
        print -depsc2 nk_ir_m_x.eps;
    end
    
   
% --------
% plot with AR(1) decaying interest rate
% ---------
      
    mcv = [0  2 4 ]'; % money to output ratio
    clear pit xt  pit_unex  xt_unex;
    for indx=1:size(mcv,1);
        mc = mcv(indx);
        [pit(:,indx),xt(:,indx),pit_unex(:,indx),xt_unex(:,indx),r1,r2,l1,l2,l3,phi,ma] = fn_find_ir(itargt2,0,t0,b,k,s,xi,mc,0,mamax);
    end;
   
    % inflation 
    if bigplot
        subplot(2,2,3)
    else
        figure
    end
    plot(tim,itargt2,'-gv','linewidth',2);
    hold on
    plot(tim,pit_unex(:,1),'--ms','linewidth',2);
    plot(tim,pit(:,1),'-rs','linewidth',2);
    if size(mcv,1) > 1;
        plot(tim,pit_unex(:,2:end),'--ms','linewidth',2);
        plot(tim,pit(:,2:end),'-rs','linewidth',2);
    end
    plot(tim,0*tim,'-k')
    if ~bigplot
        for indx = 1:size(mcv,1);
            text(2,pit_unex(2+t0,indx),['m/c=' num2str(mcv(indx),'%1.0f')],...
                'color','m','backgroundcolor','w','horizontalalignment','l');
            text(-2,pit(-2+t0,indx),['m/c=' num2str(mcv(indx),'%1.0f')],...
                'color','r','backgroundcolor','w','horizontalalignment','r');
        end;
    end
    if bigplot
        text(-4,-0.2,'m/c=4','color','r');
        text(-4,0.2,'m/c=2','color','r');
        text(2,1,'m/c=4','color','m');
    end
    axis([xlimits  -inf 1.1]);
    if ~bigplot
        legend('i','\pi, unexpected','\pi, expected','location','NorthWest');
    end
    title('Inflation')
    xlabel('Time');
    ylabel('Percent response')
    if (~bigplot) & printgraph; 
        print -depsc2 nk_ir_m2.eps; 
    end;

    % output
    if bigplot;
        subplot(2,2,4)
    else
        figure
    end
    plot(tim,itargt2,'-gv','linewidth',2);
    hold on
    %plot(tim,pit_unex(:,1),'-rs','linewidth',2);
    plot(tim,xt_unex(:,1),'--bo','linewidth',2);
    plot(tim,xt(:,1),'-ko','linewidth',2);
    plot(tim,0*tim,'-k')
    if size(mcv,1) > 1;
        plot(tim,xt_unex(:,2:end),'--bo','linewidth',2);
        plot(tim,xt(:,2:end),'-ko','linewidth',2);
    end
    
    axis([xlimits  -inf 1.1]);
    if ~bigplot
        for indx = 1:size(mcv,1);
            text(-1,xt(-1+t0,indx),['m/c=' num2str(mcv(indx),'%1.0f')],...
                'color','k','backgroundcolor','w','horizontalalignment','r');
        end;
        legend('i','x, unexpected','x, expected','location','NorthWest')
    end
    title('Output');
    xlabel('Time');
    ylabel('Percent response')
    if (~bigplot) & printgraph; 
        print -depsc2 nk_ir_m2x.eps; 
    end;
    if bigplot
        print -depsc2 nk_ir_m_4x.eps
    end;
   
end
    
   